@@ -1,6 +1,6 @@
 /* mod.h
 
-   Copyright (c) 1993-2011. Free Software Foundation, Inc.
+   Copyright (c) 1993-2012. Free Software Foundation, Inc.
 
    This file is part of GNU MCSim.
 
@@ -27,7 +27,7 @@
 
 */
 
-#ifndef _MOD_INCLUDED
+#ifndef MOD_DEFINED
 
 /* ----- Inclusions  */
 
@@ -39,11 +39,12 @@
 /* ----- Constants  */
 
 /* Version and copyright */
-#define VSZ_VERSION "v5.4.0"
-#define VSZ_COPYRIGHT "Copyright (c) 1993-2011 Free Software Foundation, Inc."
+#define VSZ_VERSION "v5.5.0"
+#define VSZ_COPYRIGHT "Copyright (c) 1993-2013 Free Software Foundation, Inc."
 
 /* The time variable accessible to the user */
 #define VSZ_TIME "t"
+#define VSZ_TIME_SBML "time"
 
 /* Maximum length of an input or output  file name */
 #define MAX_FILENAMESIZE      80   /* Arbitrary */
@@ -59,11 +60,14 @@
 #define KM_SCALE        5
 #define KM_JACOB        6
 #define KM_CALCOUTPUTS  7
+#define KM_EVENTS       8
+#define KM_ROOTS        9
 #define KM_DXDT         20
 #define KM_INLINE       30
 #define KM_SBMLMODELS   40
 #define KM_PKTEMPLATE   41
 #define KM_COMPARTMENTS 42
+#define KM_FUNCTION     43
 #define KM_END          100
 
 /* Context Types bit flags */
@@ -80,6 +84,8 @@
 #define CN_SCALE             0x0003
 #define CN_JACOB             0x0004
 #define CN_CALCOUTPUTS       0x0005
+#define CN_EVENTS            0x0006
+#define CN_ROOTS             0x0007
 #define CN_INPUTDEF          0x0100
 #define CN_TEMPLATE_DEFINED  0x0200
 #define CN_END               0x4000
@@ -104,11 +110,13 @@
 #define ID_LOCALDYN     0x5000 /* Local variables in Dynamics */
 #define ID_LOCALSCALE   0x6000 /* Local variables in Scale    */
 #define ID_LOCALJACOB   0x7000 /* Local variables in Jacobian */
+#define ID_LOCALEVENT   0x7030 /* Local variables in Events */
+#define ID_LOCALROOT    0x7060 /* Local variables in Roots */
 #define ID_LOCALCALCOUT 0x8000 /* Local variables in CalcOutputs */
 #define ID_DERIV        0x9000 /* Derivative eqn in CalcDeriv */
 #define ID_INLINE       0xA000 /* Inline statement */
 #define ID_COMPARTMENT  0xB000 /* Model compartment (for SBML processing) */
-
+#define ID_FUNCTION     0xC000 /* Function definition (for SBML processing) */
 
 /* ---------------------------------------------------------------------------
    Public Typedefs */
@@ -130,6 +138,7 @@ typedef struct tagVM {
 typedef struct tagINPUTINFO {
   WORD wContext;
   BOOL bTemplateInUse;
+  BOOL bforR;
   PSTR szInputFilename;
   PSTR szModGenName;
 
@@ -138,6 +147,8 @@ typedef struct tagINPUTINFO {
   PVMMAPSTRCT  pvmScaleEqns;
   PVMMAPSTRCT  pvmJacobEqns;
   PVMMAPSTRCT  pvmCalcOutEqns;
+  PVMMAPSTRCT  pvmEventEqns;
+  PVMMAPSTRCT  pvmRootEqns;
 
   PVMMAPSTRCT  pvmCpts;
   PVMMAPSTRCT  pvmLocalCpts;
@@ -151,9 +162,11 @@ typedef struct tagINPUTINFO {
 #define INDEX(pvm) (pvm ? (pvm)->hType & ID_INDEXMASK : ID_NULL)
 
 #define KM_TO_CN(kmCode) ((kmCode) == KM_CALCOUTPUTS ? CN_CALCOUTPUTS \
-     : (kmCode) == KM_JACOB  ? CN_JACOB \
-     : (kmCode) == KM_SCALE ? CN_SCALE \
+     : (kmCode) == KM_JACOB    ? CN_JACOB \
+     : (kmCode) == KM_SCALE    ? CN_SCALE \
      : (kmCode) == KM_DYNAMICS ? CN_DYNAMICS \
+     : (kmCode) == KM_EVENTS   ? CN_EVENTS \
+     : (kmCode) == KM_ROOTS    ? CN_ROOTS \
      : 0)
 
 
@@ -163,7 +176,7 @@ typedef struct tagINPUTINFO {
 void InitInfo (PINPUTINFO pinfo, PSTR szModGenName);
 
 
-#define _MOD_INCLUDED
+#define MOD_DEFINED
 #endif
 
 
