@@ -33,8 +33,7 @@
 
 */
 
-#ifndef _SIM_H_
-#define _SIM_H_
+#ifndef SIM_H_DEFINED
 
 /* ----------------------------------------------------------------------------
    Inclusions
@@ -51,8 +50,8 @@
 */
 
 /* Version and copyright */
-#define VSZ_VERSION "v5.4.0"
-#define VSZ_COPYRIGHT "Copyright (c) 1993-2011 Free Software Foundation, Inc."
+#define VSZ_VERSION "v5.5.0"
+#define VSZ_COPYRIGHT "Copyright (c) 1993-2013 Free Software Foundation, Inc."
 
 /* These are potential array size problems.
    Other maximum sizes are MAX_EQN and MAX_LEX in lex.h */
@@ -328,6 +327,7 @@ typedef struct tagMCVAR {
   long    lJumps;           /* Number of MH jumps for this param */
   long    lCount;           /* Number of data values eventually attached */
   double  dKernelSD;        /* MCMC jumping kernel SD */
+  double  dMaxKernelSD;     /* Maximum value of jumping kernel SD */
 
 } MCVAR, *PMCVAR; /* tagMCVAR */
 
@@ -535,7 +535,8 @@ char *SansPath (char *szFullPathname);
 void WriteArray (FILE *pfile, long cElems, double *rg);
 void WriteArrayLog (FILE *pfile, long cElems, double *rg);
 
-#endif /* _SIM_H_ */
+#define SIM_H_DEFINED
+#endif  /* SIM_H_DEFINED */
 
 /* End */
 
